#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  fpbxmotd.py
#  
#  Copyright 2012 James Finstrom <jfinstrom at gmail.com>
#  
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#  
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#  
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
#  MA 02110-1301, USA.
#  
#  
import socket
import os
import sys
import fcntl
import struct
banner="""
 _____              ____  ______  __
|  ___| __ ___  ___|  _ \| __ ) \/ /
| |_ | '__/ _ \/ _ \ |_) |  _ \\  / 
|  _|| | |  __/  __/  __/| |_) /  \ 
|_|  |_|  \___|\___|_|   |____/_/\_\                                    
"""
def getIpAddr(ifname):
	""" getIpAddr(networkInterface)
	
	By: Bryce Chidester
	Gets the IPv4 address of the provided network interface ie: eth0
	"""	
	try:
			sock  = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
	except Exception, e:
			sys.stderr.write( "Unable to open UNIX system socket: %s\n"  % e )
			return ""
	try:
			info  = fcntl.ioctl(sock.fileno(), 0x8915, struct.pack('256s', ifname[:15]))
	except IOError, e:
			# Usually this is "Does not exist"
			#sys.stderr.write( "Exception while fetching interface information for %s: %s\n" % (ifname, e) )
			(errno, errstr) = e
			sock.close()
			return "%s" % ('No IP')
			#return "Unable to fetch information for %s: %s" % (ifname, errstr)
	sock.close()
	return socket.inet_ntoa(info[20:24])
def getMacAddr(ifname):
	""" getMacAddr(networkInterface)
	
	By: Bryce Chidester
	Gets the Mac address of the provided network interface ie: eth0
	"""
	try:
			sock  = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
	except Exception, e:
			sys.stderr.write( "Unable to open UNIX system socket: %s\n"  % e )
			return ""
	try:
			info  = fcntl.ioctl(sock.fileno(), 0x8927, struct.pack('256s', ifname[:15]))
	except IOError, e:
			# Usually this is "Does not exist"
			sys.stderr.write( "Exception while fetching interface information for %s: %s\n" % (ifname, e) )
			(errno, errstr) = e
			sock.close()
			return "%s: %s" % (ifname, errstr)
			#return "Unable to fetch information for %s: %s" % (ifname, errstr)
	sock.close()
	hwaddr = []
	for char in info[18:24]:
			hwaddr.append("%02X" % ord(char))
	return ':'.join(hwaddr)
def main():
	ifdata = ''
	iflist = os.listdir('/sys/class/net/')
	for i in iflist:
		if i == 'lo':
			#Skip loopback
			continue
		ifdata += "Interface %s IP: %s\n" % (i,getIpAddr(i))
		ifdata += "Interface %s MAC: %s\n" % (i,getMacAddr(i))
	sys.stdout.write( "%s\n" % banner )
	sys.stdout.write( "%s\n" % ifdata )
	sys.stdout.write( "Please note most tasks should be handled through the FreePBX UI.\n")
	sys.stdout.write( "You can access the FreePBX GUI by typing one of the above IP's in to your web browser.\n")
	sys.stdout.write( "For support please visit http://www.freepbx.org/support-and-professional-services \n\n")
	
	return 0

if __name__ == '__main__':
	main()
